@@ -60,9 +60,9 @@ def valid_id(s):
         #ignore this one small hack to help pages use HTTP verbs
         return True
     elif _deprecated_id_re.match(s):
-        warn("The id %s will no longer be supported since it doesn't conform "
-             "to the W3C Spec: http://www.w3.org/TR/xhtml1/#C_8" % s,
-             DeprecationWarning, 3)
+        #warn("The id %s will no longer be supported since it doesn't conform "
+        #     "to the W3C Spec: http://www.w3.org/TR/xhtml1/#C_8" % s,
+        #     DeprecationWarning, 3)
         return True
     else:
         return False
@@ -248,10 +248,10 @@ class Widget(view.Renderable):
 
     def __new__(cls, id=None, parent=None, children=[], **kw):
         """
-        Takes care of Widget instances creation. Should not need to be overrien
-        likely.
+        Takes care of Widget instances creation.Should not need to be
+        overridden likely.
         """
-        obj = view.Renderable.__new__(cls,id,parent,children,**kw)
+        obj = view.Renderable.__new__(cls, **kw)
         # The previous version of this used the __dict__ attribute to update
         # things, but that doesn't fire any fset properties, and can actually
         # lose data if a property is set, the following will not behave like
@@ -968,6 +968,7 @@ class RepeatingWidgetBunch(WidgetBunch):
     def __init__(self, *args, **kw):
         super(RepeatingWidgetBunch, self).__init__(*args, **kw)
         self._repetition_cache = LRUCache(100)
+
     def __len__(self):
         return self._repetitions
 
