@@ -14,7 +14,7 @@ from itertools import imap
 import re
 import simplejson.encoder
 
-__all__ = ["js_callback", "js_function", "js_symbol"]
+__all__ = ["js_callback", "js_function", "js_symbol", "encode"]
 
 log = logging.getLogger(__name__)
 
@@ -255,3 +255,5 @@ class _js_call(object):
     
     def __unicode__(self):
         return str(self).decode(sys.getdefaultencoding())
+
+encode = TWEncoder().encode
