@@ -153,7 +153,8 @@ class ResourcesApp(object):
         return tuple((self.prefix + k, v) for k,v in self)
 
     def __iter__(self):
-        return self.iter_variant(self.ACTIVE_VARIANT)
+        return chain(self.iter_variant(self.ACTIVE_VARIANT),
+            self.iter_variant(self.DEFAULT_VARIANT))
 
     def iter_variant(self, variant):
         return imap(itemgetter(1), heapq.nlargest(len(self._dirs.setdefault(variant,[])), self._dirs.setdefault(variant, [])))
