@@ -220,7 +220,7 @@ class Renderable(object):
         """)
 
     def __new__(cls, *args, **kw):
-        obj = object.__new__(cls, *args, **kw)
+        obj = object.__new__(cls)
         obj.template = kw.pop("template", obj.template)
         engine_name = kw.pop("engine_name", None)
         if obj.template is not None:
@@ -228,7 +228,7 @@ class Renderable(object):
             # if there is a colon in the engine name, the available engines should be narrowed
             # to that engine.
             if colon_based_engine_name:
-                obj.available_engines = [colon_based_engine_name,]
+                obj.available_engines = [colon_based_engine_name]
             engine_name = colon_based_engine_name
         if engine_name:
             obj.engine_name = engine_name
